@@ -1,36 +1,12 @@
 package integration
 
 import (
-	"os"
-
 	. "github.com/containers/podman/v4/test/utils"
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
-	. "github.com/onsi/gomega/gexec"
 )
 
 var _ = Describe("Podman pod prune", func() {
-	var (
-		tempdir    string
-		err        error
-		podmanTest *PodmanTestIntegration
-	)
-
-	BeforeEach(func() {
-		tempdir, err = CreateTempDirInTempDir()
-		if err != nil {
-			os.Exit(1)
-		}
-		podmanTest = PodmanTestCreate(tempdir)
-		podmanTest.Setup()
-	})
-
-	AfterEach(func() {
-		podmanTest.Cleanup()
-		f := CurrentGinkgoTestDescription()
-		processTestResult(f)
-
-	})
 
 	It("podman pod prune empty pod", func() {
 		_, ec, _ := podmanTest.CreatePod(nil)
@@ -38,7 +14,7 @@ var _ = Describe("Podman pod prune", func() {
 
 		result := podmanTest.Podman([]string{"pod", "prune", "--force"})
 		result.WaitWithDefaultTimeout()
-		Expect(result).Should(Exit(0))
+		Expect(result).Should(ExitCleanly())
 	})
 
 	It("podman pod prune doesn't remove a pod with a running container", func() {
@@ -47,11 +23,11 @@ var _ = Describe("Podman pod prune", func() {
 
 		ec2 := podmanTest.RunTopContainerInPod("", podid)
 		ec2.WaitWithDefaultTimeout()
-		Expect(ec2).Should(Exit(0))
+		Expect(ec2).Should(ExitCleanly())
 
 		result := podmanTest.Podman([]string{"pod", "prune", "-f"})
 		result.WaitWithDefaultTimeout()
-		Expect(result).Should(Exit(0))
+		Expect(result).Should(ExitCleanly())
 
 		result = podmanTest.Podman([]string{"ps", "-qa"})
 		result.WaitWithDefaultTimeout()
@@ -67,7 +43,7 @@ var _ = Describe("Podman pod prune", func() {
 
 		result := podmanTest.Podman([]string{"pod", "prune", "-f"})
 		result.WaitWithDefaultTimeout()
-		Expect(result).Should(Exit(0))
+		Expect(result).Should(ExitCleanly())
 
 		result = podmanTest.Podman([]string{"ps", "-qa"})
 		result.WaitWithDefaultTimeout()
